# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List
from arthur_client.api_bindings.models.alert import Alert
from arthur_client.api_bindings.models.alert_bound import AlertBound
from typing import Optional, Set
from typing_extensions import Self

class AlertGroup(BaseModel):
    """
    AlertGroup
    """ # noqa: E501
    alert_rule_id: StrictStr = Field(description="The ID of the alert rule.")
    alert_rule_name: StrictStr = Field(description="The name of the alert rule.")
    count: StrictInt = Field(description="The number of alerts in this group.")
    latest_timestamp: datetime = Field(description="The timestamp of the newest alert in this group.")
    model_id: StrictStr = Field(description="The model ID associated with this alert rule.")
    model_name: StrictStr = Field(description="The name of the model associated with this alert rule.")
    bound: AlertBound = Field(description="The bound of the alert rule.")
    alerts: List[Alert] = Field(description="The list of alerts in this group.")
    __properties: ClassVar[List[str]] = ["alert_rule_id", "alert_rule_name", "count", "latest_timestamp", "model_id", "model_name", "bound", "alerts"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AlertGroup from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in alerts (list)
        _items = []
        if self.alerts:
            for _item_alerts in self.alerts:
                if _item_alerts:
                    _items.append(_item_alerts.to_dict())
            _dict['alerts'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AlertGroup from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "alert_rule_id": obj.get("alert_rule_id"),
            "alert_rule_name": obj.get("alert_rule_name"),
            "count": obj.get("count"),
            "latest_timestamp": obj.get("latest_timestamp"),
            "model_id": obj.get("model_id"),
            "model_name": obj.get("model_name"),
            "bound": obj.get("bound"),
            "alerts": [Alert.from_dict(_item) for _item in obj["alerts"]] if obj.get("alerts") is not None else None
        })
        return _obj


