# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ResourceKind(str, Enum):
    """
    ResourceKind
    """

    """
    allowed enum values
    """
    PLATFORM = 'platform'
    ORGANIZATION = 'organization'
    WORKSPACE = 'workspace'
    PROJECT = 'project'
    MODEL = 'model'
    CONNECTOR = 'connector'
    AVAILABLE_DATASET = 'available_dataset'
    DATASET = 'dataset'
    ROLE_BINDING = 'role_binding'
    ROLE = 'role'
    USER = 'user'
    GROUP = 'group'
    DATA_PLANE_ASSOCIATION = 'data_plane_association'
    DATA_PLANE = 'data_plane'
    ALERT_RULE = 'alert_rule'
    WEBHOOK = 'webhook'
    CUSTOM_AGGREGATION = 'custom_aggregation'
    CUSTOM_AGGREGATION_TEST = 'custom_aggregation_test'
    AGENT = 'agent'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ResourceKind from a JSON string"""
        return cls(json.loads(json_str))


